@@ -5,10 +5,15 @@ from unittest import mock
 import pytest
 
 from hcloud import Client
-from hcloud.placement_groups import BoundPlacementGroup, PlacementGroupsClient
+from hcloud.placement_groups import (
+    BoundPlacementGroup,
+    PlacementGroupsClient,
+)
+
+from ..conftest import BoundModelTestCase
 
 
-def check_variables(placement_group, expected):
+def check_variables(placement_group: BoundPlacementGroup, expected):
     assert placement_group.id == expected["id"]
     assert placement_group.name == expected["name"]
     assert placement_group.labels == expected["labels"]
@@ -16,12 +21,21 @@ def check_variables(placement_group, expected):
     assert placement_group.type == expected["type"]
 
 
-class TestBoundPlacementGroup:
-    @pytest.fixture()
-    def bound_placement_group(self, client: Client):
-        return BoundPlacementGroup(client.placement_groups, data=dict(id=897))
+class TestBoundPlacementGroup(BoundModelTestCase):
+    methods = [
+        BoundPlacementGroup.update,
+        BoundPlacementGroup.delete,
+    ]
 
-    def test_bound_placement_group_init(self, placement_group_response):
+    @pytest.fixture()
+    def resource_client(self, client: Client):
+        return client.placement_groups
+
+    @pytest.fixture()
+    def bound_model(self, resource_client: PlacementGroupsClient):
+        return BoundPlacementGroup(resource_client, data=dict(id=897))
+
+    def test_init(self, placement_group_response):
         bound_placement_group = BoundPlacementGroup(
             client=mock.MagicMock(), data=placement_group_response["placement_group"]
         )
@@ -30,61 +44,25 @@ class TestBoundPlacementGroup:
             bound_placement_group, placement_group_response["placement_group"]
         )
 
-    def test_update(
-        self,
-        request_mock: mock.MagicMock,
-        bound_placement_group,
-        placement_group_response,
-    ):
-        request_mock.return_value = placement_group_response
-
-        placement_group = bound_placement_group.update(
-            name=placement_group_response["placement_group"]["name"],
-            labels=placement_group_response["placement_group"]["labels"],
-        )
-
-        request_mock.assert_called_with(
-            method="PUT",
-            url="/placement_groups/{placement_group_id}".format(
-                placement_group_id=placement_group_response["placement_group"]["id"]
-            ),
-            json={
-                "labels": placement_group_response["placement_group"]["labels"],
-                "name": placement_group_response["placement_group"]["name"],
-            },
-        )
-
-        check_variables(placement_group, placement_group_response["placement_group"])
-
-    def test_delete(
-        self,
-        request_mock: mock.MagicMock,
-        bound_placement_group,
-    ):
-        delete_success = bound_placement_group.delete()
-
-        request_mock.assert_called_with(
-            method="DELETE",
-            url="/placement_groups/897",
-        )
-
-        assert delete_success is True
-
 
 class TestPlacementGroupsClient:
     @pytest.fixture()
-    def placement_groups_client(self, client: Client):
-        return PlacementGroupsClient(client)
+    def resource_client(self, client: Client):
+        return client.placement_groups
+
+    @pytest.fixture()
+    def bound_model(self, resource_client: PlacementGroupsClient):
+        return BoundPlacementGroup(resource_client, data=dict(id=897))
 
     def test_get_by_id(
         self,
         request_mock: mock.MagicMock,
-        placement_groups_client: PlacementGroupsClient,
+        resource_client: PlacementGroupsClient,
         placement_group_response,
     ):
         request_mock.return_value = placement_group_response
 
-        placement_group = placement_groups_client.get_by_id(
+        placement_group = resource_client.get_by_id(
             placement_group_response["placement_group"]["id"]
         )
 
@@ -95,7 +73,7 @@ class TestPlacementGroupsClient:
             ),
         )
 
-        assert placement_group._client is placement_groups_client
+        assert placement_group._client is resource_client
 
         check_variables(placement_group, placement_group_response["placement_group"])
 
@@ -116,13 +94,13 @@ class TestPlacementGroupsClient:
     def test_get_list(
         self,
         request_mock: mock.MagicMock,
-        placement_groups_client: PlacementGroupsClient,
+        resource_client: PlacementGroupsClient,
         two_placement_groups_response,
         params,
     ):
         request_mock.return_value = two_placement_groups_response
 
-        result = placement_groups_client.get_list(**params)
+        result = resource_client.get_list(**params)
 
         request_mock.assert_called_with(
             method="GET",
@@ -140,7 +118,7 @@ class TestPlacementGroupsClient:
         for placement_group, expected in zip(
             placement_groups, two_placement_groups_response["placement_groups"]
         ):
-            assert placement_group._client is placement_groups_client
+            assert placement_group._client is resource_client
 
             check_variables(placement_group, expected)
 
@@ -158,13 +136,13 @@ class TestPlacementGroupsClient:
     def test_get_all(
         self,
         request_mock: mock.MagicMock,
-        placement_groups_client: PlacementGroupsClient,
+        resource_client: PlacementGroupsClient,
         two_placement_groups_response,
         params,
     ):
         request_mock.return_value = two_placement_groups_response
 
-        placement_groups = placement_groups_client.get_all(**params)
+        placement_groups = resource_client.get_all(**params)
 
         params.update({"page": 1, "per_page": 50})
 
@@ -181,19 +159,19 @@ class TestPlacementGroupsClient:
         for placement_group, expected in zip(
             placement_groups, two_placement_groups_response["placement_groups"]
         ):
-            assert placement_group._client is placement_groups_client
+            assert placement_group._client is resource_client
 
             check_variables(placement_group, expected)
 
     def test_get_by_name(
         self,
         request_mock: mock.MagicMock,
-        placement_groups_client: PlacementGroupsClient,
+        resource_client: PlacementGroupsClient,
         one_placement_group_response,
     ):
         request_mock.return_value = one_placement_group_response
 
-        placement_group = placement_groups_client.get_by_name(
+        placement_group = resource_client.get_by_name(
             one_placement_group_response["placement_groups"][0]["name"]
         )
 
@@ -212,12 +190,12 @@ class TestPlacementGroupsClient:
     def test_create(
         self,
         request_mock: mock.MagicMock,
-        placement_groups_client: PlacementGroupsClient,
+        resource_client: PlacementGroupsClient,
         response_create_placement_group,
     ):
         request_mock.return_value = response_create_placement_group
 
-        response = placement_groups_client.create(
+        response = resource_client.create(
             name=response_create_placement_group["placement_group"]["name"],
             type=response_create_placement_group["placement_group"]["type"],
             labels=response_create_placement_group["placement_group"]["labels"],
@@ -237,7 +215,48 @@ class TestPlacementGroupsClient:
 
         bound_placement_group = response.placement_group
 
-        assert bound_placement_group._client is placement_groups_client
+        assert bound_placement_group._client is resource_client
         check_variables(
             bound_placement_group, response_create_placement_group["placement_group"]
         )
+
+    def test_update(
+        self,
+        request_mock: mock.MagicMock,
+        resource_client: PlacementGroupsClient,
+        bound_model,
+        placement_group_response,
+    ):
+        request_mock.return_value = placement_group_response
+
+        placement_group = resource_client.update(
+            bound_model,
+            name=placement_group_response["placement_group"]["name"],
+            labels=placement_group_response["placement_group"]["labels"],
+        )
+
+        request_mock.assert_called_with(
+            method="PUT",
+            url="/placement_groups/897",
+            json={
+                "labels": placement_group_response["placement_group"]["labels"],
+                "name": placement_group_response["placement_group"]["name"],
+            },
+        )
+
+        check_variables(placement_group, placement_group_response["placement_group"])
+
+    def test_delete(
+        self,
+        request_mock: mock.MagicMock,
+        resource_client: PlacementGroupsClient,
+        bound_model,
+    ):
+        delete_success = resource_client.delete(bound_model)
+
+        request_mock.assert_called_with(
+            method="DELETE",
+            url="/placement_groups/897",
+        )
+
+        assert delete_success is True
